@@ -32,9 +32,14 @@ developers.
   my $rdf_writer = OpenGuides::RDF->new( wiki   => $wiki,
                                          config => $config ); 
 
+  # RDF version of a node.
   print "Content-type: text/plain\n\n";
   print $rdf_writer->emit_rdfxml( node => "Masala Zone, N1 0NU" );
 
+  # Ten most recent changes.
+  print "Content-type: text/plain\n\n";
+  print $rdf_writer->make_recentchanges_rss( items => 10 );
+
 =head1 METHODS
 
 =over 4
@@ -239,8 +244,18 @@ sub emit_rdfxml {
 
 =item B<make_recentchanges_rss>
 
+  # Ten most recent changes.
   print "Content-type: text/plain\n\n";
-  print $rdf_writer->make_recentchanges_rss;
+  print $rdf_writer->make_recentchanges_rss(
+                                             items => 10,
+                                           );
+
+  # All the changes in the past week, ignoring minor edits.
+  print "Content-type: text/plain\n\n";
+  print $rdf_writer->make_recentchanges_rss(
+                                             days               => 2,
+                                             ignore_minor_edits => 1,
+                                           );
 
 =cut
 
@@ -254,13 +269,14 @@ sub make_recentchanges_rss {
 	recent_changes_link => $self->{config}->{_}->{script_url} . uri_escape($self->{config}->{_}->{script_name}) . "?RecentChanges"
      );
 
-    if ( $args{items} ) {
-        return $rssmaker->recent_changes( items => $args{items} );
-    } elsif ( $args{days} ) {
-        return $rssmaker->recent_changes( days => $args{days} );
-    } else {
-        return $rssmaker->recent_changes;
-    }
+    my %criteria;
+    $criteria{items} = $args{items} if $args{items};
+    $criteria{days} = $args{days} if $args{days};
+    $criteria{ignore_minor_changes} = $args{ignore_minor_edits}
+                                                  if $args{ignore_minor_edits};
+    $criteria{filter_on_metadata} = $args{filter_on_metadata}
+                                                  if $args{filter_on_metadata};
+    return $rssmaker->recent_changes( %criteria );
 }
 
 =back
@@ -271,7 +287,7 @@ sub make_recentchanges_rss {
 
 =item * L<CGI::Wiki>
 
-=item * The OpenGuides website which we haven't written yet.
+=item * L<http://openguides.org/>
 
 =item * L<http://chefmoz.org/>
 
@@ -283,7 +299,7 @@ The OpenGuides Project (openguides-dev@openguides.org)
 
 =head1 COPYRIGHT
 
-     Copyright (C) 2003 The OpenGuides Project.  All Rights Reserved.
+     Copyright (C) 2003-4 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
